@@ -11,8 +11,7 @@ SERVICES = (
 
 
 class Config(models.Model):
-    service = models.CharField(max_length=50, choices=SERVICES,
-                               null=False, unique=True)
+    service = models.CharField(max_length=50, choices=SERVICES, null=False)
     key = models.CharField(max_length=50, null=False, unique=True)
     value = models.CharField(max_length=100, null=False)
     date_created = models.DateTimeField(auto_now_add=True)
